import flet as ft

from requests.board_games import get_sections, get_games

def main(page: ft.Page):
    def update_games(section):
        current_section.value = section
        games = get_games(None if section == "Все" else section)
        grid.controls.clear()
        for game in games:
            grid.controls.append(
                ft.Column([
                    ft.Text(str(game)),
                    ft.Row([
                        ft.IconButton(icon=ft.icons.SHOPPING_CART),
                        ft.IconButton(icon=ft.icons.FAVORITE),
                    ]),
                ])
            )
        page.update()

    print("Rerender!")
    page.title = "Весёлые кубики"

    sections = [*get_sections(), "Все"]

    sections_buttons = [ft.Button(section, on_click=lambda e, s=section: update_games(s)) for section in sections]

    games = get_games()

    current_section = ft.Ref[str]()

    grid = ft.GridView(
        expand=1,
        runs_count=5,
        max_extent=200,
        child_aspect_ratio=1.0,
        spacing=5,
        run_spacing=5,
    )

    for game in games:
        grid.controls.append(
            ft.Column([
                ft.Text(str(game)),
                ft.Row([
                    ft.IconButton(
                        icon=ft.Icons.SHOPPING_CART
                    ),
                    ft.IconButton(
                        icon=ft.Icons.FAVORITE
                    )
                ])
            ])
        )

    page.add(
        ft.Row(
            [
                ft.Text(
                    "Весёлые кубики",
                    color="#59799f",
                    size=24,
                    weight=ft.FontWeight.BOLD,
                ),
                ft.Row([
                    ft.Button(
                        text="Вход",
                        on_click=lambda e: print("Button 1 clicked"),
                    ),
                    ft.Button(
                        text="Регистрация",
                        on_click=lambda e: print("Button 2 clicked"),
                    ),
                ])
            ],
            alignment=ft.MainAxisAlignment.SPACE_BETWEEN,  # Adjust alignment if needed
        ),
        ft.Column (
            [ft.Row(sections_buttons, alignment=ft.MainAxisAlignment.CENTER)],
            alignment=ft.MainAxisAlignment.START
        ),
        grid
    )


ft.app(main)



